"""
FileOrganizer - A Python package to organize messy files into categorized folders.
"""

from .organizer import FileOrganizer
from .cli import main

__version__ = '0.1.0'
__author__ = 'Farhan Ahmad'
__email__ = 'farhanbangash091@gmail.com'

__all__ = ['FileOrganizer', 'main']